#!/bin/sh

# $FreeBSD: ports/databases/postgresql81-server/files/pgsql.sh.tmpl,v 1.22 2006/05/23 21:18:58 girgen Exp $
#
# PROVIDE: postgresql
# REQUIRE: LOGIN
# KEYWORD: shutdown
#
# Add the following line to /etc/rc.conf to enable PostgreSQL:
#
#  postgresql_enable="YES"
#  # optional
#  postgresql_data="/usr/local/pgsql/data"
#  postgresql_flags="-w -s -m fast"
#
# This scripts takes one of the following commands:
#
#   start stop restart reload status initdb
#
# For postmaster startup options, edit ${postgresql_data}/postgresql.conf

. /etc/rc.subr

name=psa_suexec

SUEXEC_STORAGE="/usr/local/psa/bin"
OWN_SUEXEC="${SUEXEC_STORAGE}/psa-suexec"
APACHE_GROUP=www

md5_cmd="/sbin/md5"

# set defaults
psa_suexec_enable=${psa_suexec_enable:-"NO"}

load_rc_config ${name} 
rcvar=`set_rcvar`

extra_commands="status"
start_cmd="suexec_start"
stop_cmd="suexec_stop"
status_cmd="suexec_status"

md5_sys=""
md5_own=""

suexec_stop()
{
	:
}

detect_suexec_storage()
{
	local string="`/usr/local/sbin/httpd -V | grep SUEXEC_BIN=`"
	eval SYSTEM_SUEXEC="`echo $string| awk -F '=' '{print $2}'`"
}

suexec_status()
{
	detect_suexec_storage

	md5_own=`$md5_cmd ${OWN_SUEXEC} | awk '{print $4}'` 

	if [ -f ${SYSTEM_SUEXEC} ]; then
		md5_sys=`$md5_cmd ${SYSTEM_SUEXEC} | awk '{print $4}'`
	fi

	if [ "X$md5_sys" != "X$md5_own" ]; then
	    return 1
	fi

	return 0
}

suexec_start()
{
	suexec_status && return 0

	if [ "X$md5_own" != "X$md5_sys" ]; then
		cp -f ${OWN_SUEXEC} ${SYSTEM_SUEXEC} >/dev/null 2>&1
		chown root:$APACHE_GROUP ${SYSTEM_SUEXEC} >/dev/null 2>&1
		chmod 4510 ${SYSTEM_SUEXEC} >/dev/null 2>&1

		echo "Suexec utility was changed. Restarting apache."

		is_apache20="`pkg_info -qO www/apache20`"
		is_apache22="`pkg_info -qO www/apache22`"

		if [ ! -z "$is_apache20" ]; then
		    apache_suffix="apache2"
		elif [ ! -z "$is_apache22" ]; then
		    apache_suffix="apache22"
		else
		    return 2
		fi

		if [ -x "$PRODUCT_RC_D/$apache_suffix" ]; then
			service="$PRODUCT_RC_D/$apache_suffix"   
		elif [ -x "$PRODUCT_RC_D/${apache_suffix}.sh" ]; then
			service="$PRODUCT_RC_D/${apache_suffix}.sh"   
		else
			return 2
		fi

		$service restart >/dev/null 2>&1 || return 1
	fi

	return 0
}

run_rc_command "$1"
